api.system.components.runtime.v1.test_helpers.status package — Argus-Toolbelt 1.0 documentation

# api.system.components.runtime.v1.test_helpers.status package

## Submodules

## api.system.components.runtime.v1.test_helpers.status.clear_component_directory module

`api.system.components.runtime.v1.test_helpers.status.clear_component_directory.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/status, respond with HTTP 403

`api.system.components.runtime.v1.test_helpers.status.clear_component_directory.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/status, respond with HTTP 404

`api.system.components.runtime.v1.test_helpers.status.clear_component_directory.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/status, respond with HTTP 200

`api.system.components.runtime.v1.test_helpers.status.clear_component_directory.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/status, respond with HTTP 401

## api.system.components.runtime.v1.test_helpers.status.get_host_map module

`api.system.components.runtime.v1.test_helpers.status.get_host_map.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/status, respond with HTTP 403

`api.system.components.runtime.v1.test_helpers.status.get_host_map.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/status, respond with HTTP 404

`api.system.components.runtime.v1.test_helpers.status.get_host_map.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/status, respond with HTTP 200

`api.system.components.runtime.v1.test_helpers.status.get_host_map.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/status, respond with HTTP 401

## api.system.components.runtime.v1.test_helpers.status.refresh module

`api.system.components.runtime.v1.test_helpers.status.refresh.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/status/refresh, respond with HTTP 403

`api.system.components.runtime.v1.test_helpers.status.refresh.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/status/refresh, respond with HTTP 404

`api.system.components.runtime.v1.test_helpers.status.refresh.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/status/refresh, respond with HTTP 200

`api.system.components.runtime.v1.test_helpers.status.refresh.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/status/refresh, respond with HTTP 401

## Module contents